@@ -3,7 +3,7 @@ package Crypt::JWT;
 use strict;
 use warnings;
 
-our $VERSION = '0.029';
+our $VERSION = '0.030';
 
 use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw(decode_jwt encode_jwt)] );
@@ -133,7 +133,7 @@ sub _kid_lookup {
   return $found if $found->{kty} eq 'oct' && $alg =~ /^(HS|dir|PBES2-HS|A)/;
   return $found if $found->{kty} eq 'OKP' && $alg =~ /^(EdDSA|ECDH-ES)/;
   return $found if $found->{kty} eq 'EC'  && $alg =~ /^(ES|EC)/;
-  return $found if $found->{kty} eq 'RSA' && $alg =~ /^RS/;
+  return $found if $found->{kty} eq 'RSA' && $alg =~ /^(RS|PS)/;
   croak "JWT: key type '$found->{kty}' cannot be used with alg '$alg'";
 }
 
@@ -1390,4 +1390,4 @@ This program is free software; you can redistribute it and/or modify it under th
 
 =head1 COPYRIGHT
 
-Copyright (c) 2015 DCIT, a.s. L<http://www.dcit.cz> / Karel Miko
+Copyright (c) 2015-2021 DCIT, a.s. L<https://www.dcit.cz> / Karel Miko
